Env class

A cross platform version of Platform with additional powers related to the environment

Constructors

Env()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

currentDirectory ↔ Path
getter/setter pair
environment → Map<String, String>
no setter
envVarPathSeparator → String
The PATH separator for the current platform.
final
executable → String
no setter
executableArguments → List<String>
no setter
isAndroid → bool
final
isFuchsia → bool
final
isIOS → bool
final
isLinux → bool
final
isMacOS → bool
final
isWindows → bool
final
lineTerminator → String
no setter
localeName → String
no setter
localHostname → String
final
numberOfProcessors → int
final
operatingSystem → String
final
operatingSystemVersion → String
final
packageConfig → String?
no setter
pathSeparator → String
final
resolvedExecutable → String
no setter
script → Uri
no setter
version → String
final

Static Methods

envVar(String key) → String?
envVars() → Iterable<(String, String)>
joinPaths(Iterable<String> paths) → String
joins a collection of Paths appropriately for the PATH environment variable.
splitPaths(String paths) → Iterable<String>
splits a PATH environment variable string into a collection of Paths.

Constants

isWeb → const bool