LazyCellNullableAsync<T> class

A value which is asynchronously initialized on the first access. Nullable implementation of LazyCellAsync

Equality: Cells are equal if they have the same evaluated value or are unevaluated.

Hash: Cells hash to their evaluated value or hash the same if unevaluated.

Constructors

LazyCellNullableAsync(Future<T> _func())

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call() → T
Returns the previously evaluated asynchronous value of the function passed into the constructor. Will panic if the value has not yet been evaluated. Prefer force for safer context.
force() → Future<T>
Lazily evaluates the function passed into the constructor.
isEvaluated() → bool
Returns true if this has already been called, otherwise false.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override