ListSizedTCodec<T> class

Implemented types

Constructors

ListSizedTCodec(SendCodec<T> _tCodec, int tSizeInBytes)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tSizeInBytes → int
final

Methods

decode(ByteBuffer buffer) → List<T>
override
encode(List<T> data) → ByteBuffer
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited