Receiver<T> class abstract

The receiving-half of localChannel. Receivers do not close if the Sender sends an error.

Constructors

Receiver()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isBufferEmpty → bool
no setter
isClosed → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

iter() → Iter<T>
Returns an Iter that drains the current buffer.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recv() → Future<Result<T, RecvError>>
Attempts to wait for a value on this receiver, returning Err of:
recvTimeout(Duration timeLimit) → Future<Result<T, RecvError>>
Attempts to wait for a value on this receiver with a time limit, returning Err of:
stream() → Stream<T>
Returns a Stream of values ending once RecvError$Disconnected is yielded.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited