RootDir class

The root directory component, appears after any prefix and before anything else. It represents a separator that designates that a path starts from root.

Inheritance

Constructors

RootDir(bool isWindows)
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
isWindows → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override